const express = require('express');
const passport = require('passport');
const crypto = require('crypto');
const eta = require('eta');
const routes = require('./routes');
const dotenv = require('dotenv');
const path = require('path');
const cookieParser = require('cookie-parser');
const bodyParser = require('body-parser');
const flash = require('connect-flash');
dotenv.config({path: './config/config.env'})

// Need to require the entire Passport config module so app.js knows about it
require('./config/passport');


/**
 * -------------- GENERAL SETUP ----------------
 */

// Gives us access to variables set in the .env file via `process.env.VARIABLE_NAME` syntax
require('dotenv').config();

// Create the Express application
const app = express();
app.use(express.static(path.join(__dirname, 'public')));
app.use(flash());
// set the eta template engine
app.engine("eta", eta.renderFile);
app.set("view engine", "eta");
app.set('views', path.join(__dirname, 'views'));


app.use(express.json());
app.use(express.urlencoded({extended: true}));

/**
 * -------------- SESSION SETUP ----------------
 */
const session = require('express-session');
const store = new session.MemoryStore();

app.use(session({
  secret: process.env.SECRET,
  cookie: { maxAge: 6000000 },
  resave: false,
  saveUninitialized: false,
  store: store
  
  }));
  
/**
 * -------------- PASSPORT AUTHENTICATION ----------------
 */
require('./config/passport');

app.use(passport.initialize());
app.use(passport.session());

/* app.use((req, res, next) => {
	console.log(req.session);
	console.log(req.user);
	//console.log(req.user.username);
	next();
}); */

/**
 * -------------- ROUTES ----------------
 */

// Imports all of the routes from ./routes/index.js
app.use(routes);


/**
 * -------------- SERVER ----------------
 */

// Server listens on http://localhost:5000
app.listen(5000);