const router = require('express').Router(); // combines two lines: const express ... and const router
const passport = require('passport');
const eta = require('eta');
const path = require('path');
const db = require('../db');
const crypto = require('crypto');
const {isAuth, isAdmin} = require('../midw/auth');
require('../config/passport')(passport); // 'passport' module has been declared already, we seek 'passport' methods from passport.js

/**
 * -------------- POST ROUTES ----------------
 */

router.post('/login',
  passport.authenticate('local', { successRedirect: '/protected',
                                   failureRedirect: '/login',
                                   failureFlash: true })
);

router.post('/register', isAuth, function(req, res, next) {
 if (req.user) {
    const { username, password, confirmPassword } = req.body;
  if (password === confirmPassword) {
  var salt = crypto.randomBytes(16);
  crypto.pbkdf2(req.body.password, salt, 310000, 32, 'sha256', function(err, hashedPassword) {
    if (err) { return next(err); }
    
    db.run('INSERT INTO users (username, hashed_password, salt, name) VALUES (?, ?, ?, ?)', [
      req.body.username,
      hashedPassword,
      salt,
      req.body.name
    ], function(err) {
      if (err) { return next(err); }     
        res.redirect('/regsuccess');
      });
    });
  };
  } else {
        res.render('private/register', {
            message: 'Password does not match.',
            messageClass: 'alert-danger',
			title: 'Register'
        });
  }; 
});

router.post('/contact', (req, res) => {

  // Instantiate the SMTP server
  const smtpTrans = nodemailer.createTransport({
    sendmail: true,
    newline: 'unix',
    path: '/usr/sbin/sendmail'
    });

  // Specify what the email will look like
  const mailOpts = {
    from: process.env.EMAILUSER, // This is ignored
    to: process.env.EMAILUSER,
    subject: 'New message from contact form at myexample.com',
    text: `${req.body.name} (${req.body.email}) says: ${req.body.message}`
  }

  // Attempt to send the email
  smtpTrans.sendMail(mailOpts, (error, response) => {
	if (req.body.token === '41') {
    if (error) {
      res.render('contact', {
            message: 'Failure to Send Message',
            messageClass: 'alert-danger',
			title: 'Contact US'
        });
    } else {
      res.render('contact', {
            message: 'Successfully Sent Message',
            messageClass: 'alert-danger',
			title: 'Contact US'
        });
  
  };
      } else {
      res.render('contact', {
            message: 'Figure 41 not entered',
            messageClass: 'alert-danger',
			title: 'Contact US'  
     });
  };
 });
 
});
 /**
 * -------------- GET ROUTES ----------------
 */
router.get('/', (req, res) => {
    res.render("home", {
      title: "My New Site",
      message: "Welcome to My New Site!"
    });
  });
  
router.get("/aboutus", (req, res) => {
    res.render("aboutus", {
      title: "AboutUs"
    });
  });
  
router.get("/findus", (req, res) => {
    res.render("findus", {
      title: "FindUs"
    });
  });
  
router.get("/contactus", (req, res) => {
    res.render("contact", {
      title: "Contact Us"
    });
  });
  


// When you visit http://localhost:5000/login, you will see "Login Page"
router.get ('/login', (req, res) => {
    res.render('login', {
	  title: 'Login'
	});
});


// When you visit http://localhost:3000/register, you will see "Register Page"
router.get('/register', isAuth, isAdmin, (req, res) => {
        res.render('private/register', {
			title: 'Register'
  });
});

/**
 * Lookup how to authenticate users on routes with Local Strategy
 * Google Search: "How to use Express Passport Local Strategy"
 */
router.get('/protected', isAuth, (req, res) => {
        res.render('private/priv1', {
			title: 'Priv1'
		});
});

router.get('/priv2', isAuth, (req, res) => {
        res.render('private/priv2', {
			title: 'Priv2'
		});
});

router.get('/regsuccess', isAuth, (req, res) => {
        res.render('private/regsuccess', {
			title: 'Success'
		});
});

// Visiting this route logs the user out
router.get('/logout', (req, res) => {
    res.logout;
    res.redirect('/');
});


// error page for non-existent endpoints
router.get('*', (req, res) => {
    res.render("none", {
      title: "404"
    });
  });

module.exports = router;